# Contributing to PyAvatar

🎉 Thanks for taking the time to contribute! 🎉

The following is a set of guidelines for contributing to Dog Face Development Co.'s PyAvatar project on GitHub. These are mostly guidelines, not rules. Use your best judgment, and feel free to propose changes to this document in a pull request.

## Code of Conduct

This project and everyone participating in it is governed by the [Code of Conduct](CODE_OF_CONDUCT.md). By participating, you are expected to uphold this code. Please report unacceptable behavior to our [Discord](https://discord.gg/Cjwt8DRfr3).

## Signing the CLA

If you are not an employee of Dog Face Development Co. and want to submit a pull request to our open source project, you must first sign a Contributor License Agreement (CLA). This allows you to retain your ownership of the code submitted while granting Dog Face Development the necessary legal rights to use your contribution. The CLA only needs to be signed once and it covers all our projects. Follow these simple steps to sign:

- If you are creating a pull request on your own, read the [Individual CLA](https://github.com/Dog-Face-Development/PyAvatar/blob/master/docs/legal/CLA_INDIVIDUAL.md). If you are creating a pull request as part of your employment, read the [Entity CLA](https://github.com/Dog-Face-Development/PyAvatar/blob/master/docs/legal/CLA_ENTITY.md).
- Open a [pull request](https://github.com/Dog-Face-Development/PyAvatar/compare).
- The CLA Assistant bot will ask you to sign the pull request by writing the following text: `I have read the CLA Document, and I hereby sign the CLA.` If you agree to the CLA, copy the text.
- The CLA Assistant bot will mark your pull request as CLA approved, and you won't have to sign the CLA again!

## New Contributor Guide

To get an overview of the project, read the [README](README.md). Here are some resources to help you get started with open source contributions:

- [Finding ways to contribute to open source on GitHub](https://docs.github.com/en/get-started/exploring-projects-on-github/finding-ways-to-contribute-to-open-source-on-github).
- [Set up Git](https://docs.github.com/en/get-started/quickstart/set-up-git).
- [GitHub flow](https://docs.github.com/en/get-started/quickstart/github-flow).
- [Collaborating with pull requests](https://docs.github.com/en/github/collaborating-with-pull-requests).

Please contribute using [GitHub Flow](https://guides.github.com/introduction/flow). Create a branch, add commits, and [open a pull request](https://github.com/Dog-Face-Development/PyAvatar/compare).

## How to Contribute

### Did you find a bug?

- **Ensure the bug was not already reported** by searching on GitHub under [Issues](https://github.com/Dog-Face-Development/PyAvatar/issues).
- If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/Dog-Face-Development/PyAvatar/issues/new). Be sure to include a **title and clear description**, as much relevant information as possible, and a **code sample** or an **executable test case** demonstrating the expected behavior that is not occurring.
- Use the issue templates to create the issue. They include step by step guidelines and have lists of things that should be included.

### Did you write a patch that fixes a bug or updates the documentation?

- Open a new [Pull Request](https://github.com/Dog-Face-Development/PyAvatar/compare) on GitHub with the patch.
- Ensure the pull request description clearly describes the problem and solution. Be sure to include a **title**, and as much relevant information as possible. Include the relevant issue number if applicable.

### Did you fix whitespace, format code, or make a purely cosmetic patch?

- Changes that are cosmetic in nature and do not add anything substantial to the stability, functionality, or testability of PyAvatar are still accepted! Just follow the same instructions as above.
- However, do ensure that any cosmetic changes follow the Dog Face Development Co. Style Guides, found [below](#style).

### Do you intend to add a new feature or change an existing one?

- **Ensure the feature was not already introduced** by searching on GitHub under [Issues](https://github.com/Dog-Face-Development/PyAvatar/issues). Look for those under the [enhancement](https://github.com/Dog-Face-Development/PyAvatar/issues?q=is%3Aissue+is%3Aopen+label%3Aenhancement) tag.
- If you're unable to find an open issue addressing the new feature, [open a new one](https://github.com/Dog-Face-Development/PyAvatar/issues/new)!

### Do you have questions about the source code?

- Ask any question about how to use PyAvatar on our [Discord](https://discord.gg/YFMcACG9rh).
- If it does not get answered, open an [issue](https://github.com/Dog-Face-Development/PyAvatar/issues/new).  

## Coding Conventions

Start reading our code and you'll get the hang of it.

- We indent using four spaces (NOT tabs).
- Every function or piece of code should be heavily commented.
- We use [Semantic Versioning](https://semver.org/).

## Style

While contributing to a Dog Face Development Co. project, make sure your code follow our [Code Style Guide](https://github.com/Dog-Face-Development/DFD-Code-Style-Guide), and any web design elements follow our [Web Style Guide](https://github.com/Dog-Face-Development/DFD-Web-Style-Guide). If you have any changes you wish to make to the styling of our code or web projects, open an issue or pull request on the respective style guide!

## Attribution

This document is adapted from the Contributing documents of [Rails](https://github.com/rails/rails/blob/main/CONTRIBUTING.md), the [GitHub Docs](https://github.com/github/docs/blob/main/CONTRIBUTING.md), [Atom](https://github.com/atom/atom/blob/master/CONTRIBUTING.md), and [OpenGovernment](https://github.com/opengovernment/opengovernment/blob/master/CONTRIBUTING.md?plain=1).  
